@@ -5,7 +5,6 @@ from django.contrib.contenttypes.models import ContentType
 from rest_framework.viewsets import ModelViewSet
 
 from org_model_logs.models import UserAction
-from org_model_logs.serializers import UserActionSerializer
 
 logger = logging.getLogger(__name__)
 
@@ -30,7 +29,8 @@ class BaseUserActionViewSet(ModelViewSet):
         user_action = self.log_user_action(
             instance["id"], settings.ACTION_CREATE, why=why
         )
-        response.data["user_action"] = UserActionSerializer(user_action).data
+        serializer = self.get_serializer_class()
+        response.data["user_action"] = serializer(user_action).data
         return response
 
     def retrieve(self, request, *args, **kwargs):
@@ -46,7 +46,8 @@ class BaseUserActionViewSet(ModelViewSet):
         user_action = self.log_user_action(
             instance["id"], settings.ACTION_UPDATE, why=why
         )
-        response.data["user_action"] = UserActionSerializer(user_action).data
+        serializer = self.get_serializer_class()
+        response.data["user_action"] = serializer(user_action).data
         return response
 
     def partial_update(self, request, *args, **kwargs):
@@ -56,7 +57,8 @@ class BaseUserActionViewSet(ModelViewSet):
         user_action = self.log_user_action(
             instance["id"], settings.ACTION_PARTIAL_UPDATE, why=why
         )
-        response.data["user_action"] = UserActionSerializer(user_action).data
+        serializer = self.get_serializer_class()
+        response.data["user_action"] = serializer(user_action).data
         return response
 
     def destroy(self, request, *args, **kwargs):
@@ -66,5 +68,6 @@ class BaseUserActionViewSet(ModelViewSet):
         user_action = self.log_user_action(
             instance["id"], settings.ACTION_DESTROY, why=why
         )
-        response.data["user_action"] = UserActionSerializer(user_action).data
+        serializer = self.get_serializer_class()
+        response.data["user_action"] = serializer(user_action).data
         return response
